# GOAL: simulate three new patients cohorts 
# (with different covariates compared to the original data set). 
#cohort 1: 50% male / 50% female, good ECOG scores (0 or 1)
#cohort 2: 50% male / 50% female, poorer ECOG scores (2 or 3)
#cohort 3: 90% male / 10% female, good ECOG score (0 and 1)


# loading the RsSimulx library
library(RsSimulx)

# defining the path to the mlxtran project file
project.file <- "./monolix_project/43_gompertz_all_nokarnoPH_noage_nokarnoPAT.mlxtran"

#========== defining group 1
# covariate data frame for group 1, with column id and one column per covariate
cov1 <- data.frame(id=1:228,
                   sex = c(rep("F",114),rep("M",114)),
                   ecogPH = rbinom(n=228, size=1, prob=0.5)                              
                   )                             


#============= calling simulx for group 1
res1 <- simulx(project = project.file,
              parameter = cov1)

#========== defining group 2
# covariate data frame for group 2, with column id and one column per covariate
cov2 <- data.frame(id=1:228,
                   sex = c(rep("F",114),rep("M",114)),
                   ecogPH = ifelse(rbinom(n=228, size=1, prob=0.5),2,3)                              
                  )                          

#============= calling simulx
res2 <- simulx(project = project.file,
              parameter = cov2)

#========== defining group 3
# covariate data frame for group 2, with column id and one column per covariate
cov3 <- data.frame(id=1:228,
                   sex = c(rep("F",23),rep("M",205)),
                   ecogPH = rbinom(n=228, size=1, prob=0.5)                               
                  )                            

#============= calling simulx
res3 <- simulx(project = project.file,
               parameter = cov3)

# Putting together the results of the two groups
res1$Event$group <- as.factor(1)
res2$Event$group <- as.factor(2)
res3$Event$group <- as.factor(3)
res2$Event$id <- as.factor(as.integer(res2$Event$id) + 100)
res3$Event$id <- as.factor(as.integer(res3$Event$id) + 200)
EvRes <- rbind(res1$Event,res2$Event,res3$Event)

#============= plotting the KM survival curve
group.labels <- c("50% M / 50% F, ECOG 0-1", "50% M / 50% F, ECOG 2-3","90% M / 10% F, ECOG 0-1" )
kmplotmlx(EvRes,labels=group.labels,facet=FALSE) + xlab("Time (days)") + ylab("Survival") + theme(legend.justification=c(1,1), legend.position=c(0.9,0.9))
