# GOAL: doing replicates to assess the uncertainty


# loading the RsSimulx library
library(RsSimulx)

# defining the path to the mlxtran project file
project.file <- "./monolix_project/43_gompertz_all_nokarnoPH_noage_nokarnoPAT.mlxtran"

#========== defining group 1
# covariate data frame for group 1, with column id and one column per covariate
cov1 <- data.frame(id=1:228,
                   sex = c(rep("F",114),rep("M",114)),
                   ecogPH = rbinom(n=228, size=1, prob=0.5))                            


#============= calling simulx for group 1
res1 <- simulx(project = project.file,
              parameter = cov1,
              nrep = 100)

#========== defining group 2
# covariate data frame for group 2, with column id and one column per covariate
cov2 <- data.frame(id=1:228,
                   sex = c(rep("F",114),rep("M",114)),
                   ecogPH = ifelse(rbinom(n=228, size=1, prob=0.5),2,3))                             

#============= calling simulx
res2 <- simulx(project = project.file,
              parameter = cov2,
              nrep = 100)

#========== defining group 3
# covariate data frame for group 2, with column id and one column per covariate
cov3 <- data.frame(id=1:228,
                   sex = c(rep("F",23),rep("M",205)),
                   ecogPH = rbinom(n=228, size=1, prob=0.5))                             

#============= calling simulx
res3 <- simulx(project = project.file,
               parameter = cov3,
               nrep = 100)


#============= calculating the KM survival curve
kmout1 <- kmplotmlx(res1$Event,time=seq(0,1000,by=10),facet=FALSE, plot=FALSE) 
kmout2 <- kmplotmlx(res2$Event,time=seq(0,1000,by=10),facet=FALSE, plot=FALSE)
kmout3 <- kmplotmlx(res3$Event,time=seq(0,1000,by=10),facet=FALSE, plot=FALSE)
kmout1$surv$group <- as.factor(1)
kmout2$surv$group <- as.factor(2)
kmout3$surv$group <- as.factor(3)
kmout2$surv$rep <- as.factor(as.integer(kmout2$surv$rep) + 100)
kmout3$surv$rep <- as.factor(as.integer(kmout3$surv$rep) + 200)
kmout<- rbind(kmout1$surv,kmout2$surv,kmout3$surv)

colnames(kmout)[1] <- "id"
attr(kmout,"name") <- "S"
kmout$S[is.na(kmout$S)] <- 0


#============= using prctilemlx to draw prediction interval
group.labels <- c("50% M / 50% F, ECOG 0-1", "50% M / 50% F, ECOG 2-3","90% M / 10% F, ECOG 0-1" )

prctilemlx(kmout, labels=group.labels, color="#194280")+ xlab("Time (days)") + ylab("Survival") 

